==> hyakutyping-0.0.1.tar.gz: hyakutyping-0.0.1/src/Component.cpp <==
/*!
  \file
  \brief Component `

  \author Satofumi KAMIMURA

  $Id$

  \todo addDrawSurface() ȂǂÃt@CɈړAH
*/

#include "Component.h"
#include "ComponentInterface.h"
#include "SdlUtils.h"


void beego::updateDrawSurface(DrawSurface& draw_surface, Surface surface,
			      const SDL_Rect* area, const SDL_Rect& position,
			      bool position_changed) {

  // !!! EvaluateArea łĒuAȁH

  // R|[lg̈ area ̋ʕ component_area ƂȂ
  draw_surface.mustDraw = true;
  draw_surface.surface = surface;
  draw_surface.position = position;
  draw_surface.position_changed = position_changed;
  set_SdlRect(&draw_surface.area, 0, 0, position.w, position.h);

  if (draw_surface.position.x < area->x) {
    int diff = area->x - draw_surface.position.x;
    draw_surface.position.x += diff;
    draw_surface.area.x = diff;
    draw_surface.area.w -= diff;
  }
  if (draw_surface.position.y < area->y) {
    int diff = area->y - draw_surface.position.y;
    draw_surface.position.y += diff;
    draw_surface.area.y = diff;
    draw_surface.area.h -= diff;
  }
  if (draw_surface.position.x + draw_surface.area.w > area->x + area->w) {
    draw_surface.area.w -=
      (draw_surface.position.x + draw_surface.area.w) - (area->x + area->w);
  }
  if (draw_surface.position.y + draw_surface.area.h > area->y + area->h) {
    draw_surface.area.h -=
      (draw_surface.position.y + draw_surface.area.h) - (area->y + area->h);
  }

  // `̈悪ȂȂAmustDraw  false ɂ
  // !!!
}


int beego::leftPosition(Component component, int left_position) {
  return left_position;
}


int beego::centerPosition(Component component, int center_position) {
  return center_position - component->getWidth()/2;
}


int beego::rightPosition(Component component, int right_position) {
  return right_position - component->getWidth();
}


int beego::topPosition(Component component, int top_position) {
  return top_position;
}


int beego::middlePosition(Component component, int middle_position) {
  return middle_position - component->getHeight()/2;
}


int beego::bottomPosition(Component component, int bottom_position) {
  return bottom_position - component->getHeight();
}

==> hyakutyping-0.0.2.tar.gz: hyakutyping-0.0.2/src/Component.cpp <==
/*!
  \file
  \brief Component `

  \author Satofumi KAMIMURA

  $Id$

  \todo addDrawSurface() ȂǂÃt@CɈړAH
*/

#include "Component.h"
#include "ComponentInterface.h"
#include "SurfaceInterface.h"
#include "SdlUtils.h"


// !!! area, position œnႤ̂C
void beego::updateDrawSurface(DrawSurface& draw_surface, Surface surface,
			      const SDL_Rect* area, const SDL_Rect& position,
			      bool position_changed) {

  // !!! EvaluateArea łĒuAȁH

  // R|[lg̈ area ̋ʕ component_area ƂȂ
  draw_surface.mustDraw = true;
  draw_surface.surface = surface;
  draw_surface.position = position;
  draw_surface.position_changed = position_changed;
  draw_surface.is_changed = surface->isChanged();
  draw_surface.is_transparent = surface->isTransparent();
  set_SdlRect(&draw_surface.area, 0, 0, position.w, position.h);

  if (draw_surface.position.x < area->x) {
    int diff = area->x - draw_surface.position.x;
    draw_surface.position.x += diff;
    draw_surface.area.x = diff;
    draw_surface.area.w -= diff;
  }
  if (draw_surface.position.y < area->y) {
    int diff = area->y - draw_surface.position.y;
    draw_surface.position.y += diff;
    draw_surface.area.y = diff;
    draw_surface.area.h -= diff;
  }
  if (draw_surface.position.x + draw_surface.area.w > area->x + area->w) {
    draw_surface.area.w -=
      (draw_surface.position.x + draw_surface.area.w) - (area->x + area->w);
  }
  if (draw_surface.position.y + draw_surface.area.h > area->y + area->h) {
    draw_surface.area.h -=
      (draw_surface.position.y + draw_surface.area.h) - (area->y + area->h);
  }

  // `̈悪ȂȂAmustDraw  false ɂ
  // !!!
}


int beego::leftPosition(Component component, int left_position) {
  return left_position;
}


int beego::centerPosition(Component component, int center_position) {
  return center_position - component->getWidth()/2;
}


int beego::rightPosition(Component component, int right_position) {
  return right_position - component->getWidth();
}


int beego::topPosition(Component component, int top_position) {
  return top_position;
}


int beego::middlePosition(Component component, int middle_position) {
  return middle_position - component->getHeight()/2;
}


int beego::bottomPosition(Component component, int bottom_position) {
  return bottom_position - component->getHeight();
}
